@@ -1,6 +1,8 @@
+# -*- coding: utf-8 -*-
 """Higher-level classes and functions for browsing the database as a filesystem"""
 
 from .nodes import *
 from .utils import *
+from . import utils
 
 __all__ = nodes.__all__ + utils.__all__
