@@ -1,4 +1,8 @@
+# -*- coding: utf-8 -*-
 import ast
+import collections
+import functools
+from typing import Callable
 
 from pytray import obj_load
 from mincepy import qops
@@ -24,13 +28,20 @@ def parse_query(value: str) -> dict:
 
             return func(left.strip(), right)
 
-    raise ValueError("Unknown condition: {}".format(value))
+    raise ValueError(f'Unknown condition: {value}')
 
 
-OPERATORS = {
-    '=': lambda field, value: {
-        field: value
-    },
-    '>': qops.gt_,
-    '<': qops.lt_,
-}
+def apply(operator: Callable, name: str, value):
+    return {name: operator(value)}
+
+
+def _new(operator: Callable):
+    return functools.partial(apply, operator)
+
+
+OPERATORS = collections.OrderedDict([
+    ('!=', _new(qops.ne_)),
+    ('=', _new(lambda x: x)),
+    ('>', _new(qops.gt_)),
+    ('<', _new(qops.lt_)),
+])
