@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 """Module for built-in commands"""
 
 # Commands:
@@ -7,16 +8,19 @@ from .find import find
 from .history import history
 from .load import load
 from .locate import locate
+from .log import Log
 from .ls import ls
 from .meta import meta
+from .mkdir import mkdir
 from .mv import mv
 from .oid import oid
 from .pwd import pwd
 from .rm import rm
+from .rsync import rsync
 from .save import save
 from .tree import tree
 
 from . import connect
 
-__all__ = ('cat', 'cd', 'find', 'history', 'load', 'ls', 'locate', 'meta', 'mv', 'oid', 'pwd', 'rm',
-           'save', 'tree')
+__all__ = ('cat', 'cd', 'find', 'history', 'load', 'ls', 'locate', 'meta', 'mv', 'mkdir', 'oid',
+           'pwd', 'rm', 'rsync', 'save', 'tree', 'Log')
