@@ -1,5 +1,7 @@
+# -*- coding: utf-8 -*-
 """The connection commands"""
 import argparse
+import sys
 
 import cmd2
 import mincepy
@@ -12,14 +14,14 @@ class Connnection(cmd2.CommandSet):
     connect_parser.add_argument('uri', type=str, help='the URI of the archive to connect to')
 
     @cmd2.with_argparser(connect_parser)
-    def do_connect(self, app: cmd2.Cmd, args):  # pylint: disable=no-self-use
+    def do_connect(self, args):
         """Connect to a mincepy archive"""
         try:
             db.connect(args.uri)
-            app.poutput("Connected to {}".format(args.uri))
+            print(f'Connected to {args.uri}')
         except mincepy.ConnectionError as exc:
-            app.perror("Error: {}".format(exc))
+            print(f'Error: {exc}', file=sys.stderr)
 
-    def do_disconnect(self, _app: cmd2.Cmd, _cmd):  # pylint: disable=no-self-use
+    def do_disconnect(self, _args):
         """Disconnect from the current archive"""
         db.reset()
