@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 """The locate command"""
 import argparse
 from typing import Optional, Union, Sequence
@@ -5,7 +6,7 @@ from typing import Optional, Union, Sequence
 import cmd2
 
 import pyos
-from pyos import psh
+from pyos import db
 
 
 @pyos.psh_lib.command()
@@ -14,10 +15,15 @@ def locate(*obj_or_ids) -> Optional[Union[pyos.pathlib.Path, Sequence[pyos.pathl
     if not obj_or_ids:
         return None
 
-    to_locate = psh.ls(-psh.d, *obj_or_ids)
+    hist = db.get_historian()
+    obj_ids = tuple(map(hist.to_obj_id, obj_or_ids))
+
     # Convert to abspaths
-    paths = [node.abspath for node in to_locate]
-    results = pyos.psh_lib.CachingResults(paths.__iter__(), representer=str)
+    def to_path(fs_path):
+        return pyos.pathlib.Path(pyos.os.withdb.from_fs_path(fs_path))
+
+    paths = tuple(map(to_path, db.fs.get_paths(*obj_ids, historian=hist)))
+    results = pyos.psh_lib.CachingResults(iter(paths), representer=str)
 
     if len(obj_or_ids) == 1 and len(results) == 1:
         return results[0]
@@ -30,5 +36,5 @@ class Locate(cmd2.CommandSet):
     parser.add_argument('obj_ids', nargs='*', type=str)
 
     @cmd2.with_argparser(parser)
-    def do_locate(self, app: cmd2.Cmd, args):  # pylint: disable=no-self-use
-        app.poutput(locate(*args.obj_ids))
+    def do_locate(self, args):
+        print(locate(*args.obj_ids))
