@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 """Print working directory command"""
 import argparse
 
@@ -16,5 +17,5 @@ class Pwd(cmd2.CommandSet):
     parser = argparse.ArgumentParser()
 
     @cmd2.with_argparser(parser)
-    def do_pwd(self, app, _):  # pylint: disable=no-self-use
-        app.poutput(pwd())
+    def do_pwd(self, _):
+        print(pwd())
