@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 """The tree command"""
 import argparse
 
@@ -5,7 +6,7 @@ import cmd2
 
 import pyos
 from pyos import psh
-from pyos.psh import base
+from pyos.psh import completion
 
 
 @pyos.psh_lib.command(pass_options=True)
@@ -23,13 +24,13 @@ def tree(options, *paths):
 
 class Tree(cmd2.CommandSet):
     parser = argparse.ArgumentParser()
-    parser.add_argument('-L', type=int, help="max display depth of the directory tree")
-    parser.add_argument('path', nargs='*', type=str, completer_method=base.path_complete)
+    parser.add_argument('-L', type=int, help='max display depth of the directory tree')
+    parser.add_argument('path', nargs='*', type=str, completer_method=completion.path_complete)
 
     @cmd2.with_argparser(parser)
-    def do_tree(self, app: cmd2.Cmd, args):  # pylint: disable=no-self-use
+    def do_tree(self, args):
         command = tree
         if args.L is not None:
             command = command - psh.L(args.L)
 
-        app.poutput(command(*args.path))
+        print(command(*args.path))
