@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 """Library to help writing psh applications and commands"""
 
 from .opts import *
@@ -6,5 +7,6 @@ from .results import *
 from .utils import *
 from . import opts
 from . import results
+from . import utils
 
 __all__ = opts.__all__ + representers.__all__ + results.__all__ + utils.__all__
