@@ -1,6 +1,7 @@
+# -*- coding: utf-8 -*-
 import abc
 import functools
-from typing import Callable
+from typing import Callable, Union
 import types
 
 __all__ = 'command', 'Option', 'Options', 'separate_opts', 'option', 'flag'
@@ -14,20 +15,20 @@ class Option:
         self._params_stack = call_params
 
     def __str__(self):
-        parts = ["-", self.name]
+        parts = ['-', str(self.name)]
         for params in self._params_stack:
             args = params[0]
             kwargs = params[1]
 
             params = list(str(arg) for arg in args)
-            params.extend(tuple("{}={}".format(key, value) for key, value in kwargs.items()))
-            parts.extend(('(', ",".join(params), ')'))
+            params.extend(tuple(f'{key}={value}' for key, value in kwargs.items()))
+            parts.extend(('(', ','.join(params), ')'))
 
-        return "".join(parts)
+        return ''.join(parts)
 
     def __call__(self, *args, **kwargs):
         if len(self._params_stack) == 2:
-            raise RuntimeError("Option already has filled parameters")
+            raise RuntimeError('Option already has filled parameters')
 
         params = list(self._params_stack)
         params.append((args, kwargs))
@@ -54,6 +55,9 @@ class Option:
         return Option(self.name)
 
 
+OptionLike = Union[Option, int]
+
+
 class OptionSpec:
 
     def __init__(self, opt: Option, is_flag=True, help=''):  # pylint: disable=redefined-builtin
@@ -70,7 +74,7 @@ class Options:
         self._opts = {}  # typing.MutableMapping[str, Option]
 
     def __str__(self):
-        return " ".join((str(val) for val in self._opts.values()))
+        return ' '.join((str(val) for val in self._opts.values()))
 
     def __contains__(self, item):
         if isinstance(item, Option):
@@ -84,12 +88,16 @@ class Options:
         self._opts[name] = value
 
     def pop(self, opt: Option, *default):
-        if not isinstance(opt, Option):
-            raise TypeError("Unsupported option type '{}'".format(opt))
+        if not isinstance(opt, (Option, int)):
+            raise TypeError(f"Unsupported option type '{opt}'")
         if len(default) > 1:
-            raise ValueError("Can only pass at most one default")
+            raise ValueError('Can only pass at most one default')
+
+        if isinstance(opt, Option):
+            name = opt.name
+        else:
+            name = opt
 
-        name = opt.name
         return self._opts.pop(name, default[0] if default else None)
 
     def update(self, other):
@@ -97,7 +105,7 @@ class Options:
             if name not in self._opts:
                 self._opts[name] = opt
             else:
-                raise ValueError("Option '{}' alreday specified!".format(name))
+                raise ValueError(f"Option '{name}' alreday specified!")
 
 
 def separate_opts(*args) -> [Options, list]:
@@ -186,13 +194,13 @@ class Command(CommandLike):
         return builder - other
 
     def _create_docstring(self):
-        doc = [self.func.__doc__ or "Call {}".format(self.name)]
+        doc = [self.func.__doc__ or f'Call {self.name}']
         if self.accepts:
-            doc.append("FLAGS")
-            for name, spec in sorted(self.accepts.items()):
-                doc.append("\t-{}\t{}".format(name, spec.help))
+            doc.append('FLAGS')
+            for name, spec in sorted(self.accepts.items(), key=lambda pair: str(pair[0])):
+                doc.append(f'\t-{name}\t{spec.help}')
 
-        self.__call__.__func__.__doc__ = "\n".join(doc)
+        self.__call__.__func__.__doc__ = '\n'.join(doc)  # pylint: disable=no-member
 
 
 class CommandBuilder(CommandLike):
@@ -209,7 +217,7 @@ class CommandBuilder(CommandLike):
         return self.execute(*args, **kwargs)
 
     def __sub__(self, other: Option):
-        unsupported = ValueError("Command does not accept option: {}".format(other))
+        unsupported = ValueError(f'Command does not accept option: {other}')
 
         if isinstance(other, Option):
             # We have an option instance so it could be an option with a value or the
@@ -217,7 +225,7 @@ class CommandBuilder(CommandLike):
             try:
                 spec = self.command.accepts[other.name]
             except KeyError:
-                raise unsupported
+                raise unsupported from None
             else:
                 params_stack = list(other.params_stack)
 
@@ -226,7 +234,7 @@ class CommandBuilder(CommandLike):
                     if params_stack:
                         # Assume the parameters are for the command, but make sure only one
                         assert len(params_stack) == 1, \
-                            "Flag '{}' does not take any parameters".format(other.name)
+                            f"Flag '{other.name}' does not take any parameters"
                 else:
                     option_params = params_stack.pop(0)  # tuple of (args, kwargs)
                     assert not option_params[1], "Can't supply kwargs to an option"
@@ -246,7 +254,7 @@ class CommandBuilder(CommandLike):
         raise unsupported
 
     def __str__(self) -> str:
-        return " ".join((self.command.name, str(self.options)))
+        return ' '.join((self.command.name, str(self.options)))
 
 
 # endregion
@@ -268,8 +276,10 @@ def option(opt: Option, help=''):  # pylint: disable=redefined-builtin
     return attach
 
 
-def flag(opt: Option, help=''):  # pylint: disable=redefined-builtin
+def flag(opt: OptionLike, help=''):  # pylint: disable=redefined-builtin
     """Decorator for defining an option taken by a command function"""
+    opt = _make_option(opt)
+
     spec = OptionSpec(opt, is_flag=True, help=help)
 
     def attach(func):
@@ -282,3 +292,10 @@ def flag(opt: Option, help=''):  # pylint: disable=redefined-builtin
         return cmd
 
     return attach
+
+
+def _make_option(opt: OptionLike) -> Option:
+    if isinstance(opt, Option):
+        return opt
+
+    return Option(opt)
